/*-------------------------------------------------------------------------+
| Copyright 2024 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.ext.reuse.ui.commands;

import java.util.List;

import org.eclipse.jface.dialogs.IInputValidator;
import org.fortiss.tooling.ext.reuse.model.ReuseLibrary;

/**
 * Validator for new names in context of {@link ReuseLibrary}s.
 *
 * @author bergemann
 */
public class NameValidator implements IInputValidator {

	/** A list of names which already exist and thus are not allowed anymore. */
	final private List<String> existingNames;
	/** Description for what the name is used (e.g., 'reuse library'). */
	final private String nameUsage;

	/** Constructor. */
	public NameValidator(List<String> existingNames, String nameUsage) {
		this.existingNames = existingNames;
		this.nameUsage = nameUsage;
	}

	/** {@inheritDoc} */
	@Override
	public String isValid(String newText) {
		if(newText == null || newText.isEmpty() || newText.isBlank()) {
			return "A name needs to be specified.";
		}
		for(String name : existingNames) {
			if(newText.equals(name)) {
				return "A " + nameUsage + " with this name already exists. Please use another.";
			}
		}
		return null;
	}
}
