/*-------------------------------------------------------------------------+
| Copyright 2024 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.ext.reuse.ui.menus;

import static java.util.Collections.emptyList;
import static org.fortiss.tooling.ext.reuse.utils.ReuseLibraryUtilsBasics.hasReusePossibility;
import static org.fortiss.tooling.kernel.ui.service.IContextMenuService.BEFORE_GLOBAL_MENU_SECTION_ID;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.action.ActionContributionItem;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.action.IContributionItem;
import org.eclipse.jface.action.MenuManager;
import org.fortiss.tooling.ext.reuse.model.ReuseLibrary;
import org.fortiss.tooling.ext.reuse.ui.ToolingReuseUIActivator;
import org.fortiss.tooling.ext.reuse.ui.commands.AddElementToLibraryAction;
import org.fortiss.tooling.ext.reuse.ui.commands.GetUpdatedOriginsAction;
import org.fortiss.tooling.ext.reuse.ui.commands.UpdateElementFromLibraryAction;
import org.fortiss.tooling.ext.reuse.ui.commands.UpdateElementInLibraryAction;
import org.fortiss.tooling.kernel.ui.extension.IContextMenuContributor;
import org.fortiss.tooling.kernel.ui.extension.data.ContextMenuContextProvider;

/**
 * Sub context menu that contains all {@link ReuseLibrary} actions.
 *
 * @author bergemann
 */
public class ReuseLibrarySubContextMenu implements IContextMenuContributor {

	/** {@inheritDoc} */
	@Override
	public List<IContributionItem> getContributedItems(EObject selection,
			ContextMenuContextProvider contextProvider) {
		if(selection != null && canBeAdded(selection)) {
			List<IContributionItem> contributionItems = new ArrayList<IContributionItem>();

			// Group reuse library options in a separate sub menu.
			MenuManager subMenu = new MenuManager();
			subMenu.setMenuText("Reuse Manager");
			subMenu.setImageDescriptor(
					ToolingReuseUIActivator.getImageDescriptor("icons/library.png"));

			List<IAction> subMenuActions = new ArrayList<>();
			subMenuActions.add(new AddElementToLibraryAction(selection));
			subMenuActions.add(new UpdateElementInLibraryAction(selection));
			subMenuActions.add(new UpdateElementFromLibraryAction(selection));
			subMenuActions.add(new GetUpdatedOriginsAction(selection));
			for(IAction subMenuAction : subMenuActions) {
				ActionContributionItem subMenuItem = new ActionContributionItem(subMenuAction);
				subMenu.add(subMenuItem);
			}

			contributionItems.add(subMenu);

			return contributionItems;
		}
		return emptyList();
	}

	/** {@inheritDoc} */
	@Override
	public String getMenuSectionID() {
		return BEFORE_GLOBAL_MENU_SECTION_ID;
	}

	/** True if the given element can be added to {@link ReuseLibrary}. */
	protected boolean canBeAdded(EObject element) {
		return hasReusePossibility(element);
	}
}
