/*-------------------------------------------------------------------------+
| Copyright 2023 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.ext.reuse.ui.prototypes;

import static org.fortiss.tooling.ext.reuse.ui.ToolingReuseUIActivator.getDefault;
import static org.fortiss.tooling.ext.reuse.utils.ReuseLibraryUtilsBasics.getAllLocalReuseLibraries;
import static org.fortiss.tooling.ext.reuse.utils.ReuseLibraryUtilsBasics.getReuseElementName;
import static org.fortiss.tooling.kernel.utils.LoggingUtils.error;
import static org.fortiss.tooling.kernel.utils.LoggingUtils.showError;

import java.util.List;

import org.eclipse.emf.common.util.EList;
import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.ext.reuse.model.ReuseLibrary;
import org.fortiss.tooling.kernel.extension.IPrototypeProvider;
import org.fortiss.tooling.kernel.extension.base.PrototypeProviderBase;

/**
 * {@link IPrototypeProvider} for reuse elements.
 *
 * @author bergemann
 */
public final class PrototypeProvider extends PrototypeProviderBase {

	/**
	 * The default name of the roots of reuse elements, which are
	 * {@link ReuseLibrary}s.
	 */
	public static final String DEFAULT_ROOT_REUSE_ELEMENT_NAME = "Reuse Library";

	/** {@inheritDoc} */
	@Override
	protected void registerPrototypes() {
		List<ReuseLibrary> libraryList = getAllLocalReuseLibraries();
		if (libraryList == null || libraryList.isEmpty()) {
			return;
		}

		// Register all elements of all found libraries (and the libraries themselves).
		for (ReuseLibrary library : libraryList) {
			String libraryName = getReuseElementName(library);

			// The library name is also used as the category name for all contained
			// reuse elements of this library.
			String categoryName = libraryName;
			registerPrimaryPrototype(libraryName, library, categoryName);
			// Library categories should have a lower priority than standard prototype
			// categories (like "Behavioral Specification" elements).
			try {
				setPrototypeCategoryPriority(categoryName, -10);
			} catch (IllegalArgumentException e) {
				// Only in case someone changes registerPrimaryPrototype().
				error(getDefault(),
						"Error setting the category priority for the reuse library '" + categoryName + "'.", e);
				showError("Cannot set category priortiy for '" + categoryName + "'.");
			}

			EList<EObject> reuseElementList = library.getReuseElementList();
			for (EObject libraryElement : reuseElementList) {
				registerPrototype(getReuseElementName(libraryElement), libraryElement, libraryName);
			}
		}
	}
}
