/*-------------------------------------------------------------------------+
| Copyright 2022 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.ext.variability.ui.editor;

import static org.fortiss.tooling.ext.variability.ui.VariabilityUIActivator.getImageDescriptor;

import org.eclipse.jface.viewers.ColumnLabelProvider;
import org.eclipse.jface.viewers.TreeViewerColumn;
import org.eclipse.swt.graphics.Image;
import org.fortiss.variability.model.features.configuration.AlternativeFeatureConfiguration;
import org.fortiss.variability.model.features.configuration.IFeatureConfiguration;

/**
 * LabelProvider that displays checkboxes according to the elements selection.
 * 
 * @author bayha
 */
abstract class CheckBoxLabelProvider extends ColumnLabelProvider {

	/** {@inheritDoc} */
	@Override
	public Image getImage(Object element) {
		if(element instanceof AlternativeFeatureConfiguration) {
			return null;
		}
		if(isChecked(element)) {
			return getImageDescriptor("icons/checkbox_enabled.gif").createImage();
		}
		return getImageDescriptor("icons/checkbox_disabled.gif").createImage();
	}

	/**
	 * Determines for the given element, whether it should be selected in the
	 * {@link TreeViewerColumn}.
	 * 
	 * @param element
	 *            The element for which the selection shall be retrieved.
	 * @return 'true', if it shall be selected. 'false' if not.
	 */
	protected boolean isChecked(Object element) {
		if(element instanceof IFeatureConfiguration) {
			IFeatureConfiguration<?> fc = (IFeatureConfiguration<?>)element;
			return fc.isSelected();
		}
		return false;
	}
}
