/*-------------------------------------------------------------------------+
| Copyright 2022 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.ext.variability.model;

/**
 * Model element factory for variability objects in AF3.
 * 
 * @author bayha
 */
public class VariabilityModelElementFactory {

	/** Singleton for the {@link DeactivationBindingStrategy}. */
	private static final DeactivationBindingStrategy DEACTIVATION_STRATEGY_SINGLETON =
			VariabilityFactory.eINSTANCE.createDeactivationBindingStrategy();

	/**
	 * Creates a new {@link DeactivationSpecification}.
	 * 
	 * @return The newly created {@link DeactivationSpecification}.
	 */
	public static DeactivationSpecification createDeactivationSpecification() {
		return VariabilityFactory.eINSTANCE.createDeactivationSpecification();
	}

	/**
	 * Retrieves the {@link DeactivationBindingStrategy} singleton.
	 * 
	 * @return The {@link DeactivationBindingStrategy} singleton.
	 */
	public static DeactivationBindingStrategy getDeactivationStrategyInstance() {
		return DEACTIVATION_STRATEGY_SINGLETON;
	}

	/**
	 * Creates a new {@link OptionalVariationPointSpecification}.
	 * 
	 * @return The newly created {@link OptionalVariationPointSpecification}.
	 */
	public static OptionalVariationPointSpecification createOptionalVariationPointSpecification() {
		OptionalVariationPointSpecification spec =
				VariabilityFactory.eINSTANCE.createOptionalVariationPointSpecification();

		return spec;
	}
}
