/*--------------------------------------------------------------------------+
|                                                                          |
| Copyright 2022 fortiss GmbH						                       |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.variability.presence.compiler;

import static java.lang.String.format;

import java.util.ArrayList;
import java.util.List;

import javax.xml.transform.ErrorListener;

import org.antlr.v4.runtime.BaseErrorListener;
import org.antlr.v4.runtime.RecognitionException;
import org.antlr.v4.runtime.Recognizer;

/**
 * {@link ErrorListener} to be used in the {@link PresenceConditionCompiler}.
 * 
 * @author bayha
 */
public class PresenceConditionErrorListener extends BaseErrorListener {

	/** List of error messages. */
	List<String> errors = new ArrayList<String>();

	/** {@inheritDoc} */
	@Override
	public void syntaxError(Recognizer<?, ?> recognizer, Object offendingSymbol, int line,
			int charPositionInLine, String msg, RecognitionException e) {

		errors = new ArrayList<String>();

		String sourceName = recognizer.getInputStream().getSourceName();
		if(!sourceName.isEmpty()) {
			sourceName = format("%d:%d: ", line, charPositionInLine);
		}

		errors.add(sourceName + "line " + line + ":" + charPositionInLine + " " + msg);
	}

	/**
	 * Retrieves the List of error messages.
	 * 
	 * @return A {@link List} of error messages.
	 */
	public List<String> getErrors() {
		return errors;
	}

}
